@@ -1,11 +1,10 @@
+from edc_consent.constants import CONSENT_WITHDRAWAL
 from edc_constants.constants import DEAD
 from edc_visit_tracking.constants import COMPLETED_PROTOCOL_VISIT, LOST_VISIT
 
-from .constants import CONSENT_WITHDRAWAL
-
-OFF_STUDY_REASONS = (
+OFFSTUDY_REASONS = (
     (LOST_VISIT, "Lost to follow-up"),
     (COMPLETED_PROTOCOL_VISIT, "Completed protocol"),
-    (CONSENT_WITHDRAWAL, "Completed protocol"),
+    (CONSENT_WITHDRAWAL, "Consent withdrawn"),
     (DEAD, "Deceased"),
 )
